var group__micro_types =
[
    [ "microClient", "group__micro_types.html#ga22c8eebaa1ca15ba0834b89cc1081130", null ],
    [ "microClientConfig", "group__micro_types.html#ga550430b08d2e071e3901c6d720f4a039", null ],
    [ "microEndpoint", "group__micro_types.html#gaea03a1fb23faec1d7919054b27acfbc3", null ],
    [ "microEndpointConfig", "group__micro_types.html#ga7718d2f2c911e4cf677788f4ffe048cd", null ],
    [ "microEndpointInfo", "group__micro_types.html#gadd4fcc67087b4d5f42015a7269cb6496", null ],
    [ "microEndpointStats", "group__micro_types.html#ga0a429a5ecfff69b212a3ba9abebcba53", null ],
    [ "microError", "group__micro_types.html#ga41ae4121cf2f8e326369bbc2e44e20d7", null ],
    [ "microGroup", "group__micro_types.html#ga2681ea21e9f5f6681b972bbb67e32133", null ],
    [ "microGroupConfig", "group__micro_types.html#ga8ea3d2aa37d1e89fb9c6d87c10dfe603", null ],
    [ "microRequest", "group__micro_types.html#ga417ace5dc09fe8a2f6fd3882302a37c4", null ],
    [ "microService", "group__micro_types.html#gaf6f5aef8773b70746e84c100c2b19b28", null ],
    [ "microServiceConfig", "group__micro_types.html#ga1e46c0657cf42e83b366d224f380fb55", null ],
    [ "microServiceInfo", "group__micro_types.html#ga033705d0404de94efb7a6444c6e91743", null ],
    [ "microServiceStats", "group__micro_types.html#gaf832de937edc57bcc3af5e1456b3760c", null ],
    [ "micro_ErrorOutOfMemory", "group__micro_types.html#gab8c75a7c8001f647b5d2f27a0b26e82e", null ],
    [ "micro_ErrorInvalidArg", "group__micro_types.html#ga7c15167de03a8d39553afb2b81caca6b", null ]
];